% COMSOL Multiphysics - LiveLink for Matlab
% Version 6.1    1-Oct-2022
% Copyright 2010-2022 COMSOL
%
% User interface functions
%   mphcd        - Change directory to the directory of the model
%   mphdoc       - Open documentation window
%   mphlaunch    - Launch COMSOL Multiphysics Client and import a model from the server
%   mphload      - Load a COMSOL model MPH-file
%   mphopen      - GUI for opening recent model files
%   mphrun       - Run various actions on nodes
%   mphsave      - Save a COMSOL model as a file
%   mphstart     - Connect MATLAB to a COMSOL server
%   mphversion   - Return the version number of COMSOL Multiphysics
%
% Geometry functions
%   mphgeom          - Plot a geometry in a MATLAB figure
%   mphgeominfo      - Get geometry information
%   mphimage2geom    - Convert image to geometry
%   mphviewselection - Display a geometric entity selection in a MATLAB figure
%
% Mesh functions
%   mphmesh      - Plot mesh in a MATLAB figure
%   mphmeshstats - Retrieve mesh statistics and and mesh data information
%
% Utility functions
%   mphevaluate          - Evaluate parameters expressions in model
%   mphgetadj            - Return adjacency info for geometric entities
%   mphgetcoords         - Return point coordinates of geometry entities
%   mphgetu              - Return solution vector
%   mphinputmatrix       - Add a linear matrix system to a model
%   mphinterpolationfile - Save data in file readable by the Interpolation 
%                          feature
%   mphmatrix            - Get model matrices
%   mphmeasure           - Measure entites in a geometry
%   mphquad2tri          - Convert plotdata quad mesh into simplex mesh
%   mphreadstl           - Read an STL file and returns the data as a struct
%   mphreduction         - Return reduced order state space matrices for a model
%   mphselectbox         - Select geometric entity using a rubberband/box
%   mphselectcoords      - Select geometric entity using point coordinates
%   mphsolinfo           - Get information about a solution object
%   mphsolutioninfo      - Get information about solution objects and 
%                          data sets containing given parameters
%   mphstate             - Get state-space matrices for dynamic system
%   mphwritestl          - Export plot data as an STL file
%   mphxmeshinfo         - Extract information about the extended mesh
%
% Postprocessing functions
%   mphaddplotdata      - Add plot data to plotgroup
%   mphcolortable       - Return colortable data
%   mphdataset          - Plots a dataset
%   mphdatasetinfo      - Gets information about datasets
%   mpheval             - Evaluate expressions on node points
%   mphevalglobalmatrix - Evaluate matrix variables
%   mphevalpoint        - Evaluate expressions at geometry vertices
%   mphevalpointmatrix  - Evaluate matrix quantities at points in the geometry
%   mphglobal           - Evaluate global quantities
%   mphint2             - Perform integration of expressions 
%   mphinterp           - Evaluate expressions in arbitrary points or data sets
%   mphmax              - Perform maximum of expressions
%   mphmean             - Perform mean of expressions
%   mphmin              - Perform minimum of expressions
%   mphparticle         - Evaluate expressions on particle trajectories
%   mphplot             - Render a plot group in a figure window
%   mphray              - Evaluate expressions on ray trajectories
%   mphreport           - Add report to model or run report generator
%   mphsurf             - Create plot data from surf data
%   mphtable            - Get table data
%
% Model information and navigation
%   mphapplicationlibraries - GUI for viewing the Model Library
%   mphgetexpressions       - Get the model variables and parameters
%   mphgetproperties        - Get properties from a model node
%   mphgetselection         - Get information about a selection node
%   mphgetview              - Information about a view
%   mphcomponentinfo        - Gets information about components
%   mphmodel                - Return tags for the nodes and subnodes in the
%                             COMSOL model object
%   mphnavigator            - GUI for viewing the COMSOL model object
%   mphsearch               - GUI for searching expressions in the COMSOL
%                             model object
%   mphshowerrors           - Show messages in error and warning nodes in
%                             the COMSOL model object
%   mphtags                 - Return tags and names for model nodes
%   mphthumbnail            - Get and set model thumbnail images
%
% Model Manager
%   mmgetbranch             - Get branch variable in Model Manager
%   mmmodelinfo             - Model info for models stored in Model Manager or as files
%   mmsave                  - Save model in Model Manager