function [rgb,filename,info]=colortable(name,topcolorname,N)
% COLORTABLE Return a MATLAB colormap for a COMSOL color table
%
%   MAP = COLORTABLE(NAME) returns the color table (of 256 colors) for
%   NAME, where NAME can be one of the terms in the list below.
%
%   COLORTABLE(NAME) creates a plot of the colortable NAME
%
%   list = COLORTABLE returns a list of the colortables
%
%   List of colortables:
%   Name                     Description
%   -----------------------------------------------------------------------
%   AuroraAustralis |       From white through green and indigo to blue, 
%   AuroraAustralisDark     resemble the colors in the aurora australis 
%                           (southern light)
%   AuroraBorealis          From white through green and indigo to blue
%                           but with a larger indigo portion, resemble the 
%                           colors in the aurora borealis (northern light)
%   Cividis                 Suited for normal vision, a deuteranomaly, or 
%                           red-green colorblindness
%   Cyclic |                The colors begin with red, then pass through 
%   CyclicClassic(*)        yellow, green, cyan, blue, magenta, and 
%                           finally return to red
%   Dipole | DipoleDark     Developed for plots where the majority of the 
%                           solution is close to zero (or centered around 
%                           some meaningful reference point) and where, in 
%                           some places, positive and negative excitations 
%                           occur
%   Disco | DiscoDark |     From red through magenta and cyan to blue
%   DiscoLight |      
%   DiscoClassic(*)|              
%   DiscoLightClassic(*)
%   Gaia | GaiaLight        Colors that make it suitable for visualizing 
%                           plots related to topography and bathymetry
%   GrayBody |              Based on the Planckian locus for blackbody 
%   GrayBodyLight           radiation
%   GrayPrint               Varies linearly from dark gray (RGB: 0.95, 0.95, 
%                           0.95) to light gray (RGB: 0.05, 0.05, 0.05)
%   GrayScale               Linear gray scale from black to white
%   HeatCamera |
%   HeatCameraLight
%   Inferno | Magma |       Use a general bluish to reddish to yellowish 
%   Plasma                  color sequence, which is relatively friendly to 
%                           common forms of color vision deficiencies   
%   JupiterAuroraBorealis   From black through blue to white, resemble the 
%                           colors in the Jupiter's aurora
%   Prism | PrismDark       Similar to the Rainbow color table but includes 
%                           a white tip and is brighter
%   Rainbow |               The color ordering corresponds to the 
%   RainbowClassic(*) |     wavelengths of the visible part of the 
%   RainbowDark |           electromagnetic spectrum. It starts at the 
%   RainbowLight |          small-wavelength end with dark blue. The colors 
%   RainbowLightClassic(*)  range through shades of blue, cyan, green, 
%                           yellow, and red
%   Spectrum |              Similar to the Rainbow color tables but include
%   SpectrumClassic(*) |    violet at the small-wavelength end of the 
%   SpectrumLight           visible spectrum
%   Thermal |               Uses equal distances from dark red to orange, 
%   ThermalClassic(*) |     yellow, and white, which means that the region 
%   ThermalDark |           with the lowest values is red instead of black 
%   ThermalLight |          as in the ThermalClassic color table. The 
%   ThermalLightClassic(*)  colors correspond to the colors iron takes as 
%                           it heats up
%   ThermalWave |           Designed for wave phenomena with a thermal 
%   ThermalWaveDark         character. It is calibrated to have a 100% 
%                           symmetric luminance
%   Traffic |               From green through yellow to red
%   TrafficClassic(*) |
%   TrafficLight |
%   TrafficLightClassic(*)
%   Twilight                From pink through white to blue 
%   Viridis                 Uses a general bluish to greenish to yellowish 
%                           color sequence, which is relatively friendly to 
%                           common forms of color vision deficiencies
%   Wave | WaveClassic(*)   Linearly from blue to red. These color tables 
%   | WaveLight |           are useful for data that naturally has positive 
%   WaveLightClassic        and negative attributes in addition to a 
%                           magnitude
%
%   (*) The classic version corresponds to a colortable used in COMSOL 
%   Multiphysics earlier than version 6.0
%
%   See the entry colortable in the LiveLink for MATLAB User's Guide for 
%
%   Example:
%     m = colortable('Rainbow');
%
%     % Make a plot of the 'prism' colortable
%     colortable('Prism')

%   Copyright 2010-2022 COMSOL
