function [pg,pl]=mphaddplotdata(model, varargin)
% MPHADDPLOTDATA  Add a data plot to a model
%
%   Valid property/value pairs include:
%   Property     Value/{Default}            Description
%   -----------------------------------------------------------------------
%   arrowtype    {arrow} | arrowhead | cone Arrow type
%   arrowbase    head | {tail} | center     Arrow base
%   clearplot    on | {off}                 Clear plot group
%   color        vector | string | index    Color specification
%                | matrix 
%   colortable   string | cell array        Color table name
%   data         matrix                     Coordinate data
%   edges        {on} | off                 Plot data set edges
%   elementdata  matrix                     Element data (low level)
%   latex        {off} | on                 Use LaTeX markup
%   normaldata   matrix                     Data for normals (low level)
%   plotgroup    string                     Plot group tag
%   radius       vector                     Radius for tubes
%   type         arrow | line | surface     Plot type
%                | annotation | tube 
%                | point
%   vector       matrix                     Direction vector
%
% Example 1:
% v = linspace(0, 2*pi, 10);
% xy = [sin(v); cos(v)]; 
% mphaddplotdata(model, 'plotgroup', 'pg1', ...
%  'type', 'line', ...
%  'data', xy, ...
%  'color', 'b');
% mphplot(model, 'pg1')
%
% Example 2:
% [x,y] = meshgrid(-25:25, -25:25);
% r = sqrt(x.^2+y.^2);
% r(r==0) = 1;
% z = sin(r)./r;
% mphaddplotdata(model, 'plotgroup', 'pg1', ...
%  'type', 'surface', ...
%  'data', {x y z*20}, ...
%  'color', r);

% Copyright 2018-2022 COMSOL
