function [d,data]=mphgeominfo(model,geomtag,varargin)
% MPHGEOMINFO Get geometry information
% 
% INFO = MPHGEOMINFO(MODEL, GEOMTAG) gets information about the geometry
% GEOMTAG in the model MODEL.
%
%   [INFO,DATA] = MPHGEOMINFO(MODEL, GEOMTAG, 'ENTITY', ENTITY, ...)  
%   retrieves additional information about the entity level ENTITY.
%
%   Valid property/value pairs include:
%   Property       Value/{Default}       Description
%   -----------------------------------------------------------------------
%   entity         'vertex' | 'edge' |   Geometric entity to select
%                  'face'
%   selection      Positive integer      Selection
%                  array | {[]}  
%   steps          Positive integer      Number of point for data 
%                  array {10}            evaluation
%
%   See the entry mphgeominfo in the LiveLink for MATLAB User's Guide for
%   more information about the INFO structure.
%
% Example:
%     % Get model geometry information:
%     model = mphopen('model_tutorial_llmatlab.mph');
%     info = mphgeominfo(model)
%     % Get geometry data for face number 4:
%     [info, data] = mphgeominfo(model,'geom1','entity','face',...
%         'selection',4);
%     % Get geometry data for face number 4 using a 5x10 grid:
%     [info, data] = mphgeominfo(model,'geom1','entity','face',...
%         'selection',4,'steps',[5 10]);
%
% See also: mphcomponentinfo, mphmeshstats

%   Copyright 2010-2022 COMSOL
