function [n,nn]=mphgetadj(model, geomtag, returntype, adjtype, adjnumber)
% MPHGETADJ Return geometry entity indices that are adjacent to each other
%
%   N = MPHGETADJ(MODEL,GEOMTAG,RETURNTYPE,ADJTYPE,ADJNUMBER) returns the
%   indices of all the adjacent geometry entities.
%
%   [N, M] = MPHGETADJ(MODEL,GEOMTAG,RETURNTYPE,ADJTYPE,ADJNUMBER) returns 
%   the indices of all the adjacent geometry entities in N. M contains the 
%   indices of entities that connect the entities the best.
%
%   RETURNTYPE is the type of geometry entities whose index are returned.
%   ADJTYPE is the type of input geometry entity.
%   The entity type can be one of 'point', 'edge', 'boundary' or 'domain'.
%   See the entry MPHGETADJ in the LiveLink for MATLAB User's Guide for
%   more information about the entity type definition.
%
%   Example :
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%
%     % Return the indices of the boundaries adjacent to point 2:
%     bnd_idx = mphgetadj(model, 'geom1', 'boundary', 'point', 2)
%
%     % Return the indices of the points adjacent to domain 2:
%     pt_idx = mphgetadj(model, 'geom1', 'point', 'domain', 2)
%
%   See also: mphgetcoords, mphselectbox, mphselectcoords, mphmeasure

%   Copyright 2010-2022 COMSOL
