function [retprop,allowedprop]=mphgetproperties(p, varargin)
% MPHGETPROPERTIES Get the properties from a model node
%
%   STR = MPHGETPROPERTIES(MODELNODE) returns the structure STR containing
%   the properties that are defined for the node MODELNODE.
%
%   [STR, ALLOWED] = MPHGETPROPERTIES(MODELNODE) also returns the structure
%   ALLOWED containing the allowed values for corresponding properties.
%
%   Valid property/value pairs include:
%   Property           Value/{Default}       Description
%   -----------------------------------------------------------------------
%   Propnames          Cell array of         List of properties to show only
%                      strings
%   Returnstring      {'on'} | 'off'        Return expressions as string
%   Showsel            'on' | {'off'}        Return the properties selection
%
%   Example:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Build the mesh
%     model.mesh('mesh1').run;
%     % Get the mesh size properties
%     str = mphgetproperties(model.mesh('mesh1').feature('size'))
%     % Get the mesh size properties and their allowed values:
%     [str, allowed] = mphgetproperties(model.mesh('mesh1').feature('size'))
%     % Get the min/max mesh size properties only
%     str = mphgetproperties(model.mesh('mesh1').feature('size'),...
%     'propnames',{'hmax','hmin'})
%     % Return the properties data not as string
%     str = mphgetproperties(model.mesh('mesh1').feature('size'),...
%     'propnames',{'hmax','hmin'},'returnstrings','off')
%
%   See also: mphgetproperties, mphgetselection, mphmodel, mphnavigator,
%   mphsearch

%   Copyright 2011-2022 COMSOL
