function data=mphgetselection(node)
% MPHGETSELECTION Get information about a selection node
%
%   INFO = MPHGETSELECTION(SELNODE) returns selection data of the selection
%   node SELNODE.
%
%   The output INFO is a MATLAB structure defined with the following fields:
%   Field              Description
%   -----------------------------------------------------------------------
%   Dimension          Space dimension of the geometry entity selected
%   Geom               Geometry tag
%   Entities           Indexes of the selected entities
%   IsGlobal           Boolean expression that indicates if the selection
%                      is global
%
%   Example:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Add a selection node to the model
%     model.selection.create('ball1', 'Ball');
%     model.selection('ball1').set('entitydim', '2');
%     model.selection('ball1').set('posz', '11e-3');
%     model.selection('ball1').set('r', '1e-5');
%     % Get the information of the selection node model.selection('ball1')
%     info = mphgetselection(model.selection('ball1'))
%
%   See also: mphgetexpressions, mphgetproperties, mphmodel, mphnavigator,
%   mphsearch

% Copyright 2011-2022 COMSOL
