function mphinterpolationfile(filename, type, data, varargin)
% MPHINTERPOLATIONFILE Save data in files readable by the Interpolation feature
%
%   MPHINTERPOLATION(FILENAME,TYPE,DATA) saves the NxN matrix DATA 
%   available in workspace into the text file FILENAME with the format
%   TYPE. The interpolation coordinates are vectors with values from 1 to N and 
%   1 to M.
%
%   MPHINTERPOLATION(FILENAME,TYPE,DATA,XDATA) saves the vector DATA and 
%   the interpolation coordinate XDATA available in workspace into the text
%   file FILENAME with the format TYPE.
%
%   MPHINTERPOLATION(FILENAME,TYPE,DATA,XDATA,YDATA) saves the matrix DATA 
%   and the interpolation coordinate vectors XDATA and YDATA available in 
%   workspace into the text file FILENAME with the format TYPE.
%
%   FILENAME is the full name of the size, including the path where to save
%   it.
%   TYPE can be either 'grid', 'sectionwise' or 'spreadsheet'.
%
%   Example:
%     % Create random 10x10 interpolation data to file using grid format:
%     data = cumsum(0.1*randn(size(10)));
%     mphinterpolationfile('data_grid.txt', 'grid', data);
%
%     % Save 1D interpolation data to file using spreadsheet format:
%     t = 0:0.05:2*pi;
%     z = sin(cos(t)*4)+sin(51*t)*0.05;
%     mphinterpolationfile('data_spreadsheet.txt', 'spreadsheet', z, t);
%
%     % Save 2D interpolation data to file using sectionwise format:
%     z = magic(9); x = 1:9; y = 0:8;
%     mphinterpolationfile('data_sectionwise.txt', 'sectionwise', z, x, y);
%
%   See also:  mphquad2tri, mphreadstl, mphsurf, mphwritestl

%   Copyright 2012-2022 COMSOL
