function [model,filenameloaded]=mphload(filename, tag, hist)
% MPHLOAD Load a COMSOL Multiphysics model MPH-file
%
%   MODEL = MPHLOAD(FILENAME) loads a COMSOL model object saved with 
%   the name FILENAME and assigns the default tag "Model". The model 
%   object is returned as the variable MODEL.
%
%   MODEL = MPHLOAD(FILENAME, MTAG) loads a COMSOL model object saved with 
%   the name FILENAME and assigns the tag "Model". The model object is 
%   returned as the variable MODEL.
%
%   MODEL = MPHLOAD(FILENAME, MTAG, '-history') turns on history recording,
%   which is turned off by default when using MPHLOAD.
%
%   MODEL = MPHLOAD(FILENAME, MTAG, PWD) opens the protected file using the
%   supplied password PWD.
%
%   MODEL = MPHLOAD(MTAG) link the model already loaded on the COMSOL server 
%   with the tag MTAG. The model object is accessible at the MATLAB prompt
%   using the variable MODEL.
%
%   MODEL = MPHLOAD(LOCATION, ...) loads a COMSOL model object saved in 
%   Model Nanager with the location variable LOCATION.
%
%   [MODEL, FILENAMELOADED] = MPHLOAD(FILENAME,...) also returns the full
%   filename FILENAMELOADED including the path of the file that is loaded.
%
%   The model tag MTAG and the password PWD are defined as strings.
%   If the model tag is the same as a model that is currently in the COMSOL
%   server, the loaded model overwrites the existing one unless the
%   existing model is used by another client.
%   Note that MATLAB searches for the model on the MATLAB path if an
%   absolute path is not supplied.
%   The extension 'mph' can be omitted.
%
%   Example:
%     % Load the file model_tutorial_llmatlab.mph:
%     model = mphload('model_tutorial_llmatlab')
%
%     % Load the file model_tutorial_llmatlab.mph and set the model name in
%     % the COMSOL server to Model2:
%     model = mphload('model_tutorial_llmatlab','Model2')
%
%     % Load MyModel.mph with the path specified:
%     model = mphload('PATH\MyModel.mph')
%
%     % Load model_tutorial_llmatlab.mph and return the filename:
%     [model, filename] = mphload('model_tutorial_llmatlab')
%
%   See also: mphsave

%   Copyright 2010-2022 COMSOL
