function [m1,m2]=mphmeasure(model,geomtag,entity,varargin)
% MPHMEASURE measure entites in a geometry
%
% [measure,misc]=mphmeasure(model,geomtag,entity,...)
%
% ENTITY can be one of 'point', 'edge', 'boundary' or 'domain'.
% Selection is optional. Default is 'all'
%
% Return values:
% ENTITY        measure       misc
% point         Centroid      Distance between 2 points
% edge          Length
% boundary      Area
% domain        Volume        Surface area
%
% Valid property/value pairs include:
%   Property           Value/{Default}    Description
%   -----------------------------------------------------------------------
%   build              {'on'} | 'off' |   Build the geometry before
%                      string  plotting
%   selection          Positive integer   Selection (finalized geometry)
%                      array | {[]}
%   objects            Cell array         Selection matrix
%   usefinal           {'on'} | 'off'     Measure on the finalized geometry
%
% Examples:
% % Get volume of all domains in the geometry (geom1)
% mphopen busbar
% m = mphmeasure(model, '', 'domain')
%
% % Get midpoint and distance between points 2 and 4
% [m,dist] = mphmeasure(model, 'geom1', 'point', 'selection', [2 4])
%
% % Length of edges bounded by vertex 1, 29, 41 and 42
% [~,a] = mphgetadj(model, '', 'edge', 'point', [1 29 41 42]);
% mphviewselection(model, '', [1 29 41 42], 'point')
% hold on
% mphviewselection(model, '', a, 'edge', 'edgecolorselected', 'b')
% m = mphmeasure(model, '', 'edge', 'selection', a)
%
% See also: mphgetcoords, mphgetadj, mphselectbox, mphselectcoords

% Copyright 2017-2022 COMSOL
