function pd = mphray(model,varargin)
% MPHRAY  Evaluate expressions on ray trajectories
%
%   PD = MPHRAY(model) returns the positions of each ray at all time
%   steps stored in model with a single Particle/Ray dataset.
%
%   PD = MPHRAY(model,'EXPR',{E1,...,EN},...) returns position, velocity
%   and expressions e1, ..., en evaluated on ray trajectories.
%
%   Valid property/value pairs include:
%   Property       Value/{Default}        Description
%   -----------------------------------------------------------------------
%   expr         String | Cell array       Expressions to evaluate
%                {''}
%   dataonly     {'off'} | 'on'            Return only expression values
%   dataset      String {''}               Data set tag
%   evaluate     Positive integer | scalar Rays to evaluate
%   t            Double array {[]}         Time for evaluation
%   solnum       Positive integer array |  Inner solution for evaluation
%                'end' | {'all'}
%   outersolnum  Positive integer {1} |	   Solution number for parametric
%                                          sweep
%   times        {'on'} | 'off'            Return times
%   velocities   'on' | {'off'}            Return velocities
%
%   PD is a structure with the following fields:
%      p           - Position of the rays
%      v           - Velocity of the rays
%      d#          - Result of evaluation #
%      t           - Time for evaluation
%      expr        - Evaluated expressions
%      unit        - Unit of evaluations
%
%   Note that MPHRAY only evaluates expressions using ray data sets.
%
%   See also: mphparticle, mpheval, mphevalpoint, mphint2, mphinterp

%   Copyright 2012-2022 COMSOL
