function mphsave(varargin)
% MPHSAVE Save a COMSOL model as a file
%
%   MPHSAVE saves the model that is loaded on the server
%
%   MPHSAVE(MODEL) saves MODEL as a COMSOL MPH-file.
%
%   MPHSAVE(MODEL,FILENAME) saves MODEL to the file named FILENAME.
%
%   MPHSAVE(FILENAME) saves the unique COMSOL model that is loaded on the 
%   server to the file named FILENAME.
%
%   MPHSAVE(MTAG) saves the COMSOL model loaded on the COMSOL server with 
%   the tag MTAG.
%
%   MPHSAVE(MTAG,FILENAME) saves the COMSOL model loaded on the COMSOL 
%   server with the tag MTAG to the file named FILENAME.
%
%   Valid property/value pairs include:
%   Property     Value/{Default}     Description
%   -----------------------------------------------------------------------
%   component    {'off'} | 'on'      Save M-file using component syntax
%   copy         {'off'} | 'on'      Save a copy of the model
%   description  String              Set or append model description
%   excludeData  'on' | 'off'        Exclude built, computed, and plotted 
%                                    data
%   filenameis   {'fullpath'} |      Use filename as the selected type
%                'name' | 'path'
%   optimize     'speed' |           Optimize MPH-files for speed or size
%                'size'
%   store        {'on'} | 'off'      Store the filename in most recently
%                                    used files
%   title        String              Set model title
%   thumbnail    FIGHANDLE           Set model thumbnail
%
%   If the file name is not provided, the model has to be saved previously.
%   If the file name does not include a path, the file is saved relatively 
%   to the current path in MATLAB.
%   The model can be saved as an MPH-file, Java-file, VBA-file or M-file. 
%   The file extension determines which format that is saved.
%
%   See also: mphopen, mphload, mphthumbnail, mmsave

%   Copyright 2011-2022 COMSOL
