function ss=mphsolinfo(model,varargin)
% MPHSOLINFO Get information about a solution object
%
%   INFO = MPHSOLINFO(MODEL,...) returns information about the solution
%   object.
%
%   Valid property/value pairs include:
%   Property       Value/{Default}      Description
%   -----------------------------------------------------------------------
%   soltag         String {''}          Solution node tag
%   dataset        String {''}          Data set tag
%   NU             {'off'} | 'on'       Get info about number of solutions
%
%   INFO is a struct with the following fields:
%   Field           Description
%   -----------------------------------------------------------------------
%   soltag          Solution node tag
%   study           Study node tag
%   size            Size of the solution vector
%   nummesh         Number of meshes in the solution (for automatic
%                   remeshing)
%   sizes           Size of the solution vector for each mesh and number
%                   of timesteps/parameters for each mesh
%   soltype         Solver type (Stationary, Parametric, Time or
%                   Eigenvalue)
%   solpar          Name of the parameter
%   sizesolvals     Length of the parameter list
%   solvals         Values of the parameters, eigenvalues or time steps
%   paramsweepnames Parametric sweep parameter names
%   paramsweepvals  Parametric sweep parameter values
%   label           Solution node label
%   batch           Information about solutions for parametric sweeps
%   dataset         List of data sets that directly use the solution
%   savepointtag    Save point tag
%   NUsol           Number of solution vectors stored
%   NUreacf         Number of reaction forces vectors stored
%   NUadj           Number of adjacency vectors stored
%   NUfsens         Number of functional sensitivity vectors stored
%   NUsens          Number of forward sensitivity vectors stored
%
%   Example 1:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study:
%     std.run;
%
%     % Get the information about the default solution object:
%     solinfo = mphsolinfo(model)
%
%   Example 2: Get information of multiple solver solution
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Get the information about the 1st outer solution (power = 30):
%     solinfo = mphsolinfo(model,'soltag','sol3')
%
%     % Get the solution vector for 2nd outer solution (power = 60):
%     solinfo = mphsolinfo(model,'soltag','sol4')
%
%   See also: mphgetu, mphxmeshinfo, mphsolutioninfo

%   Copyright 2011-2022 COMSOL
