function info = mphtable(model,tabletag)
% MPHTABLE Get table data from table or evaluation group
%
%   INFO = MPHTABLE(MODEL,TABLETAG) returns the structure INFO containing 
%   the table data with the TABLETAG tag and its headers.
%
%   INFO is a structure with the following fields:
%      headers   - Headers for the table
%      tag       - Tag of the table
%      data      - Data of the extracted table
%      filename  - Filename when table exported to file 
%
%   Example:
%     % Load model_tutorial_llmatlab.mph, add a stationary study and compute
%     % the solution for different power values:
%     model = mphopen('model_tutorial_llmatlab');
%     std = model.study.create('std');
%     stat = std.feature.create('stat','Stationary');
%     stat.setIndex('pname', 'power', 0);
%     stat.setIndex('plistarr', '30 60 90', 0);
%     std.run;
%
%     % Evaluate the maximum temperature in the model, set the results in a
%     % table:
%     max = model.result.numerical.create('max', 'MaxVolume');
%     max.selection.all;
%     tbl = model.result.table.create('tbl', 'Table');
%     tbl.comments('Volume Maximum (T)');
%     max.set('table', 'tbl');
%     max.setResult;
%
%     % Extract the table data:
%     str = mphtable(model,'tbl');
%     tbl_data = str.data
% 
%   See also: mpheval, mphevalpoint, mphglobal, mphint2, mphinterp, 
%   mphmax, mphmean, mphmin

%   Copyright 2012-2022 COMSOL
